@@ -1,14 +1,26 @@
 import subprocess
 import numpy as np
 import pandas as pd
-import os
+import os, sys
 
 # Set the value Display variable
 os.environ.setdefault('DISPLAY', ':0.0')
 
 # Simple function to perform bash operations 
 def bash_command(cmd): 
-    subprocess.run(['/bin/bash', '-c', cmd], stderr=subprocess.DEVNULL, stdout=subprocess.DEVNULL)
+    if os.name == 'nt':
+        try:
+            subprocess.run(['C:\\cygwin64\\bin\\bash.exe', '-l', cmd],  stderr=subprocess.DEVNULL, stdout=subprocess.DEVNULL)
+        except:
+            try:
+                subprocess.run(['C:\\cygwin\\bin\\bash.exe', '-l', cmd],  stderr=subprocess.DEVNULL, stdout=subprocess.DEVNULL)
+            except:
+                sys.exit('Windows platforms need cygwin64/cygwin to run this subprocess')
+        
+    elif os.name == 'posix':    
+        subprocess.run(['/bin/bash', '-c', cmd], stderr=subprocess.DEVNULL, stdout=subprocess.DEVNULL)
+    else:
+        sys.exit('Could not verify OS')
     return 0
 
 # ──────────────────────────────── RUNNING HASHRF RETURNING CLEANED OUTPUT ─────
