@@ -54,6 +54,7 @@ try:
     from .embeddings import PCA_e, tSNE_e
     from .calculate_distances import hashrf
     from .calculate_distances import maple_RF
+    from .calculate_distances import tqdist
     from .interactive_mode import interactive
     from .embeddings.graph import graph
     from .subsample import subsample
@@ -62,6 +63,7 @@ except:
     from embeddings import PCA_e, tSNE_e
     from calculate_distances import hashrf
     from calculate_distances import maple_RF
+    from calculate_distances import tqdist
     from interactive_mode import interactive
     from embeddings.graph import graph
     from subsample import subsample
@@ -125,11 +127,13 @@ class tree_set():
         methods = {'hashrf' : hashrf.hashrf,
                    'hashrf_weighted' : hashrf.hashrf_weighted,
                    'days_RF' : maple_RF.calculate_distance_matrix,
+                   'quartet' : tqdist.quartet,
+                   'triplet' : tqdist.triplet,
                    'None' : None, }
 
         with self.console.status("[bold green]Calculating distances...") as status:
             self.distance_matrix = methods[method](self.file, self.n_trees, self.output_file)
-        print(f'[bold red]{method} | Done!')
+        print(f'[bold blue]{method} | Done!')
     
     # ─── EMBED ─────────────────────────────────────────────────────────────────
     def embed(self, method, dimensions):
